@@ -135,10 +135,10 @@ int32_t SPVM__Net__SSLeay__BIO__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
   
-  BIO* bio = env->get_pointer(env, stack, obj_self);
+  BIO* pointer = env->get_pointer(env, stack, obj_self);
   
   if (!env->no_free(env, stack, obj_self)) {
-    BIO_free(bio);
+    BIO_free(pointer);
   }
   
   return 0;
