@@ -44,13 +44,13 @@ If SSL_CTX_new failed, an exception is thrown with C<eval_error_id> set to the b
 
 C<method set_mode : long ($mode : long);>
 
-Calls native L<SSL_CTX_set_mode|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_mode> function given $mode, and returns the updated mode.
+Calls native L<SSL_CTX_set_mode|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_mode> function given the pointer value of the instance, $mode, and returns the updated mode.
 
 =head2 set_verify
 
 C<method set_verify : void ($mode : int);>
 
-Calls native L<SSL_CTX_set_verify|https://docs.openssl.org/master/man3/SSL_CTX_set_verify/> function given $mode.
+Calls native L<SSL_CTX_set_verify|https://docs.openssl.org/master/man3/SSL_CTX_set_verify/> function given the pointer value of the instance, $mode.
 
 =head2 get0_param
 
@@ -62,7 +62,7 @@ Calls native L<SSL_CTX_get0_param|https://docs.openssl.org/master/man3/SSL_CTX_g
 
 C<method load_verify_locations : int ($path : string);>
 
-Calls native L<SSL_CTX_load_verify_locations|https://docs.openssl.org/master/man3/SSL_CTX_load_verify_locations/> function given $path, and returns its return value.
+Calls native L<SSL_CTX_load_verify_locations|https://docs.openssl.org/master/man3/SSL_CTX_load_verify_locations/> function given the pointer value of the instance, $path, and returns its return value.
 
 Exceptions:
 
@@ -82,7 +82,7 @@ If SSL_CTX_set_default_verify_paths failed, an exception is thrown with C<eval_e
 
 C<method use_certificate_file : int ($file : string, $type : int);>
 
-Calls native L<use_certificate_file|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate/> function given $file, $type, and returns its return value.
+Calls native L<use_certificate_file|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate/> function given the pointer value of the instance, $file, $type, and returns its return value.
 
 Exceptions:
 
@@ -94,7 +94,7 @@ If SSL_CTX_use_certificate_file failed, an exception is thrown with C<eval_error
 
 C<method use_certificate_chain_file : int ($file : string);>
 
-Calls native L<use_certificate_chain_file|https://docs.openssl.org/1.1.1/man3/SSL_CTX_use_certificate/> function given $file, and returns its return value.
+Calls native L<use_certificate_chain_file|https://docs.openssl.org/1.1.1/man3/SSL_CTX_use_certificate/> function given the pointer value of the instance, $file, and returns its return value.
  
 Exceptions:
 
@@ -104,7 +104,7 @@ If SSL_CTX_use_certificate_chain_file failed, an exception is thrown with C<eval
 
 C<method use_PrivateKey_file : int ($file : string, $type : int);>
 
-Calls native L<use_PrivateKey_file|https://docs.openssl.org/3.1/man3/SSL_CTX_use_certificate> function given $file, $type, and returns its return value.
+Calls native L<use_PrivateKey_file|https://docs.openssl.org/3.1/man3/SSL_CTX_use_certificate> function given the pointer value of the instance, $file, $type, and returns its return value.
 
 Exceptions:
 
@@ -116,7 +116,7 @@ If SSL_CTX_use_PrivateKey_file failed, an exception is thrown with C<eval_error_
 
 C<method set_cipher_list : int ($str : string);>
 
-Calls native L<set_cipher_list|https://docs.openssl.org/master/man3/SSL_CTX_set_cipher_list/> function given $str, and returns its return value.
+Calls native L<set_cipher_list|https://docs.openssl.org/master/man3/SSL_CTX_set_cipher_list/> function given the pointer value of the instance, $str, and returns its return value.
 
 Exceptions:
 
@@ -128,7 +128,7 @@ If SSL_CTX_set_cipher_list failed, an exception is thrown with C<eval_error_id>
 
 C<method set_ciphersuites : int ($str : string);>
 
-Calls native L<set_ciphersuites|https://docs.openssl.org/master/man3/SSL_CTX_set_cipher_list/> function given $str, and returns its return value.
+Calls native L<set_ciphersuites|https://docs.openssl.org/master/man3/SSL_CTX_set_cipher_list/> function given the pointer value of the instance, $str, and returns its return value.
 
 Exceptions:
 
@@ -146,7 +146,7 @@ Calls native L<SSL_CTX_set_cert_store|https://docs.openssl.org/master/man3/SSL_C
 
 C<method set_options : long ($options : long);>
 
-Calls native L<set_options|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_options> function given $options, and returns its return value.
+Calls native L<set_options|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_options> function given the pointer value of the instance, $options, and returns its return value.
 
 =head2 get_options
 
@@ -158,7 +158,7 @@ Calls native L<SSL_CTX_get_options|https://docs.openssl.org/3.1/man3/SSL_CTX_set
 
 C<method clear_options : long ($options : long);>
 
-Calls native L<SSL_CTX_clear_options|https://docs.openssl.org/3.1/man3/SSL_CTX_set_options/> function given $options, and returns its return value.
+Calls native L<SSL_CTX_clear_options|https://docs.openssl.org/3.1/man3/SSL_CTX_set_options/> function given the pointer value of the instance, $options, and returns its return value.
 
 =head2 set_alpn_protos
 
@@ -218,13 +218,13 @@ If set1_curves_list failed, an exception is thrown with C<eval_error_id> set to
 
 C<method set_session_cache_mode : long ($mode : long);>
 
-Calls native L<SSL_CTX_set_session_cache_mode|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_session_cache_mode/> function given $mode, and returns its return value.
+Calls native L<SSL_CTX_set_session_cache_mode|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_session_cache_mode/> function given the pointer value of the instance, $mode, and returns its return value.
 
 =head2 set_ecdh_auto
 
 C<method set_ecdh_auto : long ($state : int);>
 
-Calls native L<SSL_CTX_set_ecdh_auto|https://docs.openssl.org/3.1/man3/SSL_CTX_set_tmp_ecdh/> function given $state, and returns its return value.
+Calls native L<SSL_CTX_set_ecdh_auto|https://docs.openssl.org/3.1/man3/SSL_CTX_set_tmp_ecdh/> function given the pointer value of the instance, $state, and returns its return value.
 
 Exceptions:
 
@@ -244,19 +244,19 @@ If set_tmp_dh failed, an exception is thrown with C<eval_error_id> set to the ba
 
 C<method set_post_handshake_auth : void ($val : int);>
 
-Calls native L<SSL_CTX_set_post_handshake_auth|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_verify> function given $val.
+Calls native L<SSL_CTX_set_post_handshake_auth|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_verify> function given the pointer value of the instance, $val.
 
 =head2 use_PrivateKey
 
 C<method use_PrivateKey : int ($pkey : L<Net::SSLeay::EVP_PKEY|SPVM::Net::SSLeay::EVP_PKEY>);>
 
-Calls native L<SSL_CTX_use_PrivateKey|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate> function given $pkey, pushes $pkey to the end of L</"pkeys_list"> field, and returns the return value of the native function.
+Calls native L<SSL_CTX_use_PrivateKey|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate> function given the pointer value of the instance, $pkey, pushes $pkey to the end of L</"pkeys_list"> field, and returns the return value of the native function.
 
 =head2 set_session_id_context
 
 C<method set_session_id_context : int ($sid_ctx : string, $sid_ctx_len : int = -1);>
 
-Calls native L<SSL_CTX_set_session_id_context|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_alpn_select_cb> function given $sid_ctx, $sid_ctx_len, and returns its return value.
+Calls native L<SSL_CTX_set_session_id_context|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_alpn_select_cb> function given the pointer value of the instance, $sid_ctx, $sid_ctx_len, and returns its return value.
 
 If $sid_ctx_len is less than 0, it is set to the length of $sid_ctx.
 
@@ -270,7 +270,7 @@ If SSL_CTX_set_session_id_context failed, an exception is thrown with C<eval_err
 
 C<method set_min_proto_version : int ($version : int);>
 
-Calls native L<SSL_CTX_set_min_proto_version|https://docs.openssl.org/master/man3/SSL_CTX_set_min_proto_version> function given $version, and returns its return value.
+Calls native L<SSL_CTX_set_min_proto_version|https://docs.openssl.org/master/man3/SSL_CTX_set_min_proto_version> function given the pointer value of the instance, $version, and returns its return value.
 
 Exceptions:
 
@@ -280,7 +280,7 @@ If SSL_CTX_set_min_proto_version failed, an exception is thrown with C<eval_erro
 
 C<method set_client_CA_list : void ($list : L<X509_NAME|SPVM::X509_NAME>[]);>
 
-Calls native L<set_client_CA_list|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_client_CA_list> function given $list.
+Calls native L<SSL_CTX_set_client_CA_list|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_client_CA_list> function given the pointer value of the instance, $list.
 
 Exceptions:
 
@@ -290,7 +290,7 @@ The list $list must be defined. Otherwise an exception is thrown.
 
 C<method add_client_CA : int ($cacert : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509>);>
 
-Calls native L<add_client_CA|https://docs.openssl.org/master/man3/SSL_CTX_set0_CA_list> function given $cacert, and returns its return value.
+Calls native L<SSL_CTX_add_client_CA|https://docs.openssl.org/master/man3/SSL_CTX_set0_CA_list> function given the pointer value of the instance, $cacert, and returns its return value.
 
 Exceptions:
 
@@ -302,13 +302,47 @@ If add_client_CA failed, an exception is thrown with C<eval_error_id> set to the
 
 C<method add_extra_chain_cert : long ($x509 : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509>);>
 
-Calls native L<add_extra_chain_cert|https://docs.openssl.org/1.1.1/man3/SSL_CTX_add_extra_chain_cert/> function given $x509, sets the C<no_free> flag of $x509 is set to 1, and returns its return value.
+Calls native L<SSL_CTX_add_extra_chain_cert|https://docs.openssl.org/1.1.1/man3/SSL_CTX_add_extra_chain_cert/> function given the pointer value of the instance, $x509, sets the C<no_free> flag of $x509 is set to 1, and returns its return value.
 
 Exceptions:
 
 The X509 object $x509 must be defined. Otherwise an exception is thrown.
 
-If add_extra_chain_cert failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
+If SSL_CTX_add_extra_chain_cert failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
+
+=head2 set_tlsext_servername_callback
+
+C<method set_tlsext_servername_callback : long ($cb : L<Net::SSLeay::Callback::TlsextServername|SPVM::Net::SSLeay::Callback::TlsextServername>, $arg : object = undef);>
+
+Calls native L<SSL_CTX_set_tlsext_servername_callback|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_tlsext_servername_callback> function given $cb, and returns its return value.
+
+$arg is expected to be passed to native L<SSL_CTX_set_tlsext_servername_arg|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_tlsext_servername_callback> function.
+
+=head2 set_tlsext_status_cb
+
+C<method set_tlsext_status_cb : long ($cb : L<Net::SSLeay::Callback::TlsextStatus|SPVM::Net::SSLeay::Callback::TlsextStatus>, $arg : object = undef);>
+
+Calls native L<SSL_CTX_set_tlsext_status_cb|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_tlsext_status_cb> function given $cb, and returns its return value.
+
+$arg is expected to be passed to native L<SSL_CTX_set_tlsext_status_arg|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_tlsext_status_cb> function.
+
+Exceptions:
+
+If SSL_CTX_set_tlsext_status_cb failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
+
+=head2 set_default_passwd_cb
+
+C<method set_default_passwd_cb : void ($cb : L<Net::SSLeay::Callback::PemPasswd|SPVM::Net::SSLeay::Callback::PemPasswd>, $arg : object = undef);>
+
+Calls native L<SSL_CTX_set_default_passwd_cb|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_default_passwd_cb> function given $cb, and returns its return value.
+
+$arg is expected to be passed to native L<SSL_CTX_set_default_passwd_cb_userdata|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_default_passwd_cb> function.
+
+=head2 set_psk_client_callback
+
+C<method set_psk_client_callback : void ($cb : L<Net::SSLeay::Callback::PskClient|SPVM::Net::SSLeay::Callback::PskClient>);>
+
+Calls native L<SSL_CTX_set_psk_client_callback|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_psk_client_callback> function given $cb.
 
 =head2 DESTROY
 
